@@ -1,6 +1,6 @@
 ##
 ## R package splines2 by Wenjie Wang and Jun Yan
-## Copyright (C) 2016-2020
+## Copyright (C) 2016-2021
 ##
 ## This file is part of the R package splines2.
 ##
@@ -29,10 +29,10 @@
 ##'     associated M-spline instead of actual polynomial degree. For example,
 ##'     I-spline basis of degree 2 is defined as the integral of associated
 ##'     M-spline basis of degree 2.
-##' @param intercept If \code{TRUE} by default, all spline bases are included.
-##'     Notice that when using I-Spline for monotonic regression,
-##'     \code{intercept = TRUE} should be set even when an intercept term is
-##'     considered additional to the spline bases in the model.
+##' @param intercept If \code{TRUE} by default, all of the spline basis
+##'     functions are returned.  Notice that when using I-Spline for monotonic
+##'     regression, \code{intercept = TRUE} should be set even when an intercept
+##'     term is considered additional to the spline basis functions.
 ##' @param derivs A non-negative integer specifying the order of derivatives of
 ##'     I-splines.
 ##'
@@ -40,7 +40,7 @@
 ##'
 ##' @references
 ##' Ramsay, J. O. (1988). Monotone regression splines in action.
-##' \emph{Statistical science}, 3(4), 425--441.
+##' \emph{Statistical Science}, 3(4), 425--441.
 ##'
 ##' @example inst/examples/ex-iSpline.R
 ##'
@@ -55,7 +55,7 @@ iSpline <- function(x, df = NULL, knots = NULL, degree = 3L,
 {
     ## check inputs
     if ((derivs <- as.integer(derivs)) < 0) {
-        stop("'derivs' must be a non-negative integer.")
+        stop("The 'derivs' must be a non-negative integer.")
     }
     if (derivs > 0) {
         return(mSpline(x = x,
@@ -68,13 +68,13 @@ iSpline <- function(x, df = NULL, knots = NULL, degree = 3L,
     }
     ## else I-Spline basis
     if ((degree <- as.integer(degree)) < 0)
-        stop("'degree' must be a nonnegative integer.")
+        stop("The 'degree' must be a nonnegative integer.")
     if (is.null(df)) {
         df <- 0L
     } else {
         df <- as.integer(df)
         if (df < 0) {
-            stop("'df' must be a nonnegative integer.")
+            stop("The 'df' must be a nonnegative integer.")
         }
     }
     knots <- null2num0(knots)
@@ -91,12 +91,14 @@ iSpline <- function(x, df = NULL, knots = NULL, degree = 3L,
               x
           }
     ## call the engine function
-    out <- rcpp_iSpline_basis(
+    out <- rcpp_iSpline(
         x = xx,
         df = df,
         degree = degree,
         internal_knots = knots,
         boundary_knots = Boundary.knots,
+        derivs = derivs,
+        integral = FALSE,
         complete_basis = intercept
     )
     ## throw warning if any x is outside of the boundary
@@ -104,7 +106,7 @@ iSpline <- function(x, df = NULL, knots = NULL, degree = 3L,
     if (any((xx < b_knots[1L]) | (xx > b_knots[2L]))) {
         warning(wrapMessages(
             "Some 'x' values beyond boundary knots",
-            "may cause ill-conditioned bases."
+            "may cause ill-conditioned basis functions."
         ))
     }
     ## keep NA's as is
