@@ -138,3 +138,7 @@ expect_error(deriv(dbsMat, - 1))
 meta_obj <- matrix(1:10, nrow = 10, ncol = 5)
 class(meta_obj) <- c("matrix", "bSpline")
 expect_error(deriv(meta_obj))
+
+## check attributes
+attr(bsMat, "degree") <- NULL
+expect_error(deriv(bsMat), "degree")
