@@ -145,8 +145,8 @@ expect_true(isNumMatrix(mSpline(x, degree = 0, intercept = TRUE),
 expect_error(mSpline(x, degree = 0))
 expect_error(mSpline(x, degree = 0, derivs = 1))
 
-## error if any internal knot is not placed inside of boundary
-expect_error(mSpline(x, knots = c(0, 0.5), degree = 0))
+## error if any internal knot is placed outside boundary
+expect_error(mSpline(x, knots = c(- 0.1, 0.5), degree = 0))
 
 ## warning if any x outside of boundary
 expect_warning(mSpline(c(x, 10), knots = knots, degree = 0,
